Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(501)

Unified Diff: dart/tests/language/is_not_class2_test.dart

Issue 60293003: Version 0.8.10.5 (Closed) Base URL: http://dart.googlecode.com/svn/trunk/
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « dart/tests/language/instanceof3_test.dart ('k') | dart/tests/language/isnot_malformed_type_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dart/tests/language/is_not_class2_test.dart
===================================================================
--- dart/tests/language/is_not_class2_test.dart (revision 29908)
+++ dart/tests/language/is_not_class2_test.dart (working copy)
@@ -2,10 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Dart test program for catch that we expect a class after an 'is'. This is
-// not a negative test since 'aa' is a malformed type and therefore should be
-// treated as dynamic.
+// Dart test program for catch that we expect a class after an 'is'. 'aa' is a
+// malformed type and a type error should be thrown upon test.
+import 'package:expect/expect.dart';
+
class A {
const A();
}
@@ -23,5 +24,5 @@
}
main() {
- IsNotClass2NegativeTest.testMain();
+ Expect.throws(IsNotClass2NegativeTest.testMain, (e) => e is TypeError);
}
« no previous file with comments | « dart/tests/language/instanceof3_test.dart ('k') | dart/tests/language/isnot_malformed_type_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698